==> zio-aws-route53recoverycontrolconfig_2.12-5.17.116.1-sources.jar: zio/aws/route53recoverycontrolconfig/model/RuleConfig.scala <==
package zio.aws.route53recoverycontrolconfig.model
import java.lang.Integer
import zio.aws.route53recoverycontrolconfig.model.primitives.{
  __integer,
  __boolean
}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class RuleConfig(
    inverted: __boolean,
    threshold: __integer,
    `type`: zio.aws.route53recoverycontrolconfig.model.RuleType
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.RuleConfig = {
    import RuleConfig.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.RuleConfig
      .builder()
      .inverted(__boolean.unwrap(inverted): java.lang.Boolean)
      .threshold(__integer.unwrap(threshold): Integer)
      .`type`(`type`.unwrap)
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.RuleConfig.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.RuleConfig.wrap(buildAwsValue())
}
object RuleConfig {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.RuleConfig
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.route53recoverycontrolconfig.model.RuleConfig =
      zio.aws.route53recoverycontrolconfig.model
        .RuleConfig(inverted, threshold, `type`)
    def inverted: __boolean
    def threshold: __integer
    def `type`: zio.aws.route53recoverycontrolconfig.model.RuleType
    def getInverted: ZIO[Any, Nothing, __boolean] = ZIO.succeed(inverted)
    def getThreshold: ZIO[Any, Nothing, __integer] = ZIO.succeed(threshold)
    def getType: ZIO[
      Any,
      Nothing,
      zio.aws.route53recoverycontrolconfig.model.RuleType
    ] = ZIO.succeed(`type`)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.RuleConfig
  ) extends zio.aws.route53recoverycontrolconfig.model.RuleConfig.ReadOnly {
    override val inverted: __boolean =
      zio.aws.route53recoverycontrolconfig.model.primitives
        .__boolean(impl.inverted())
    override val threshold: __integer =
      zio.aws.route53recoverycontrolconfig.model.primitives
        .__integer(impl.threshold())
    override val `type`: zio.aws.route53recoverycontrolconfig.model.RuleType =
      zio.aws.route53recoverycontrolconfig.model.RuleType.wrap(impl.`type`())
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.RuleConfig
  ): zio.aws.route53recoverycontrolconfig.model.RuleConfig.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-route53recoverycontrolconfig_2.13-5.17.197.2-sources.jar: zio/aws/route53recoverycontrolconfig/model/RuleConfig.scala <==
package zio.aws.route53recoverycontrolconfig.model
import java.lang.Integer
import zio.aws.route53recoverycontrolconfig.model.primitives.{
  __integer,
  __boolean
}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class RuleConfig(
    inverted: __boolean,
    threshold: __integer,
    `type`: zio.aws.route53recoverycontrolconfig.model.RuleType
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.RuleConfig = {
    import RuleConfig.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.RuleConfig
      .builder()
      .inverted(inverted: java.lang.Boolean)
      .threshold(threshold: Integer)
      .`type`(`type`.unwrap)
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.RuleConfig.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.RuleConfig.wrap(buildAwsValue())
}
object RuleConfig {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.RuleConfig
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.route53recoverycontrolconfig.model.RuleConfig =
      zio.aws.route53recoverycontrolconfig.model
        .RuleConfig(inverted, threshold, `type`)
    def inverted: __boolean
    def threshold: __integer
    def `type`: zio.aws.route53recoverycontrolconfig.model.RuleType
    def getInverted: ZIO[Any, Nothing, __boolean] = ZIO.succeed(inverted)
    def getThreshold: ZIO[Any, Nothing, __integer] = ZIO.succeed(threshold)
    def getType: ZIO[
      Any,
      Nothing,
      zio.aws.route53recoverycontrolconfig.model.RuleType
    ] = ZIO.succeed(`type`)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.RuleConfig
  ) extends zio.aws.route53recoverycontrolconfig.model.RuleConfig.ReadOnly {
    override val inverted: __boolean = impl.inverted(): __boolean
    override val threshold: __integer = impl.threshold(): __integer
    override val `type`: zio.aws.route53recoverycontrolconfig.model.RuleType =
      zio.aws.route53recoverycontrolconfig.model.RuleType.wrap(impl.`type`())
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.RuleConfig
  ): zio.aws.route53recoverycontrolconfig.model.RuleConfig.ReadOnly =
    new Wrapper(impl)
}
